==> peperit_2.0_estable.zip: themes/peperit/html_files/terminos_y_condiciones.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 12/Enero/2015
	// Versión 1.0 Términos y condiciones adaptados a los datos de configuración de la Shop::
	//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
?>
 <?php
 // Incluimos la miga
   	//escupirMiga("Términos y condiciones");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Aviso Legal & Términos de uso', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
	<div class="col-md-12">
<article id="textos_legales">
	
	      <p><?= traducir('En cumplimiento con el deber de información dispuesto en la Ley 34/2002 de Servicios de la Sociedad de la Información y el Comercio Electrónico (LSSI-CE) de 11 de julio, se facilitan a continuación los siguientes datos de información general de este sitio web:'); ?></p>

                <p><?= traducir('La titularidad de este sitio web %-Shop::$configuracion->url-%, (en adelante, sitio Web o %-Shop::$empresa->nombre-%) la ostenta: %-Shop::$empresa->nombre_legal-%, con NIF %-Shop::$empresa->cif-%, cuyos datos de contacto son:'); ?></p>

                <p><?= traducir('Dirección: %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-%, %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%)');?></p>
                <p><?= traducir('Teléfono: (+34) %-Shop::$empresa->telefono_empresa-%'); ?></p>
                <p><?= traducir('E-Mail: %-Shop::$empresa->email_empresa-%'); ?></p>

                <p><?= traducir('El uso o el acceso a este sitio implica que usted (en adelante usuario) reconoce haber leído y comprendido las presentes condiciones legales de uso, y las acepta en su totalidad. Les rogamos por tanto que lea atentamente las presentes Condiciones, así como nuestra Política de Privacidad antes de formalizar su pedido.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% se reserva en todo caso el derecho a  revisar unilateralmente y sin previo aviso las presentes condiciones o términos de uso, así como los precios e información de los servicios que aparecen en la misma. ');?><?=traducir('Todas las modificaciones entrarán en vigor inmediatamente después de ser publicadas en este sitio. Es de la exclusiva responsabilidad de los usuarios revisar las presentes condiciones periódicamente y, en caso de no estar de acuerdo, en todo o en parte con las mismas abstenerse de utilizar nuestro sitio web.'); ?></p>

                <h3><?= traducir('Acceso y normas de utilización del sitio web'); ?></h3>
                <ul>
                    <li><?= traducir('•	%-Shop::$empresa->nombre_legal-% se reserva el derecho a modificar en cualquier momento, unilateralmente y sin necesidad de previa notificación a sus usuarios, los contenidos, la estructura, el funcionamiento o las condiciones de acceso de este sitio. Así mismo %-Shop::$empresa->nombre_legal-% se reserva el derecho a suspender temporalmente, sin necesidad de previo aviso, el acceso a este sitio para realizar operaciones de mantenimiento, actualización, mejora o de reparación.'); ?></li>

                    <li><?= traducir('•	El Usuario se obliga a utilizar la Página Web y todo su contenido y servicios conforme a lo establecido en la ley, la moral, y el orden público. Asimismo, se obliga hacer un uso adecuado de los servicios y/o contenidos de la Página Web y a no emplearlos para realizar actividades ilícitas o constitutivas de delito, que atenten contra los derechos de terceros y/o que infrinjan la regulación sobre propiedad intelectual e industrial, o cualesquiera otras normas del ordenamiento jurídico aplicable. ');?><?=traducir('%-Shop::$empresa->nombre_legal-% se reserva el derecho de anular la cuenta de aquellos Usuarios que hagan un uso inapropiado de la misma o no respeten las observaciones y prohibiciones previstas por estos Términos de Uso.'); ?></li>

                    <li><?= traducir('•	Los servicios ofrecidos en %-Shop::$configuracion->url-% se dirigen exclusivamente, a personas mayores de 18 años de edad. El usuario manifiesta y garantiza que tiene la edad legal para formalizar un contrato vinculante con %-Shop::$empresa->nombre_legal-%, y que toda la información que nos facilite a través de los formularios es exacta y veraz. '); ?></li>

                    <li><?= traducir('•	El usuario no podrá realizar ningún pedido especulativo, falso o fraudulento. Si %-Shop::$empresa->nombre_legal-% tuviera indicios razonables para considerar que se ha hecho un pedido de esta índole estará autorizado a anularlo e informar a las autoridades pertinentes.'); ?></li>

                    <li><?= traducir('•	El Usuario se obliga a mantener indemne a %-Shop::$empresa->nombre_legal-% ante cualquier posible reclamación, multa, pena o sanción que pueda venir obligada a soportar como consecuencia del incumplimiento por parte del Usuario de cualquiera de las normas de utilización antes indicadas, reservándose, además, el titular de la Página Web el derecho a solicitar la indemnización por daños y perjuicios que corresponda.'); ?></li>

                    <li><?= traducir('•	El uso de los contenidos y servicios ofrecidos por %-Shop::$empresa->nombre_legal-% será bajo el exclusivo riesgo y responsabilidad del usuario. %-Shop::$empresa->nombre_legal-% no asume ningún deber o compromiso de verificar ni de vigilar los contenidos e informaciones introducidos por los usuarios.'); ?></li>
                </ul>
                <h3><?= traducir('Privacidad'); ?></h3>
                <p><?= traducir('Puede consultar toda la información sobre el tratamiento de sus datos personales en el apartado [Política de Privacidad]'); ?></p>
                <p><?= traducir('Si desea obtener cualquier información adicional sobre nuestra Política de Privacidad puede enviar una solicitud por correo ordinario a %-Shop::$empresa->nombre_legal-%, %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-%, %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%), o contactar con nosotros a través del correo electrónico  a la siguiente dirección %-Shop::$empresa->email_empresa-%'); ?></p>
                <h3><?= traducir('Propiedad intelectual e industrial.'); ?></h3>

                <p><?= traducir('Todos los contenidos del sitio web %-Shop::$configuracion->url-%, incluyendo, a título enunciativo y no limitativo, las marcas comerciales, logotipos, gráficos, imágenes, archivos de sonido y vídeo, software, código de programación, textos, iconos, y los nombres que identifican servicios (en adelante "los materiales") están protegidos por los derechos de autor y otros derechos sobre la propiedad intelectual de %-Shop::$empresa->nombre_legal-% y de los demás titulares legítimos. ');?><?=traducir('Se considera reservada la reproducción en todo o en parte, de cualquier manera y bajo cualquier forma de %-Shop::$configuracion->url-% y sus contenidos sin el consentimiento explícito y por escrito de %-Shop::$empresa->nombre_legal-%'); ?></p>

                <p><?= traducir('El acceso del usuario a este sitio no implica ningún tipo de renuncia, transmisión ni cesión, total o parcial, de dichos derechos de propiedad, por esta razón, el acceso a estos contenidos o elementos no otorga, bajo ningún concepto, al usuario la posibilidad de su copia, venta, modificación, reproducción, publicación, cesión, transmisión, o creación de nuevos productos o servicios derivados de la información y elementos aquí contenidos.'); ?></p>

                <p><?= traducir('Es por ello que el usuario de este sitio no podrá, salvo previa autorización expresa y por escrito de %-Shop::$empresa->nombre_legal-%, copiar, distribuir, descargar, modificar, suprimir, borrar, alterar, publicar, transmitir, o aprovecharse de cualquier forma de los materiales que contiene.'); ?></p>

                <p><?= traducir('El usuario no adquiere derechos o licencia en relación con el servicio ni los elementos en el mismo, excepto el derecho limitado a utilizar el servicio de acuerdo con las condiciones aplicables. ');?><?=traducir('Únicamente podrá utilizar los contenidos o elementos a los que acceda a través de los servicios de %-Shop::$empresa->nombre_legal-% para su propio uso y necesidades, obligándose a no realizar ni directa, ni indirectamente una explotación comercial, ni de los servicios, ni de los materiales, elementos, o información obtenidos a través de los mismos.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% no se responsabiliza del contenido de %-Shop::$configuracion->url-% sea veraz ni de que esté debidamente actualizado. %-Shop::$empresa->nombre_legal-% no responderá de la autoría de los materiales y contenidos  de terceros de los que no sea titular, ni de posibles violaciones de derechos de propiedad intelectual frente a terceros en relación con dichos materiales.'); ?></p>

                <h3><?= traducir('Limitación de responsabilidad.'); ?></h3>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% no se responsabilizará en forma alguna de cualquier daño directo o indirecto, lucro cesante o pérdida de datos y /o clientes que se deriven del uso por parte de los usuarios o de la imposibilidad de uso de este sitio web.'); ?></p>

                <p><?= traducir('Este sitio puede contener vínculos hipertextuales (Links) y remisiones a otros sitios y páginas web que pueden no estar controlados por %-Shop::$empresa->nombre_legal-%, en estos casos %-Shop::$empresa->nombre_legal-% no se responsabilizará de los contenidos que puedan aparecer en dichas páginas.'); ?></p>

                <p><?= traducir('El usuario acepta expresamente dejar exenta a %-Shop::$empresa->nombre_legal-% de cualquier responsabilidad de los actos u omisiones del usuarios basadas en los contenidos alojados en este sitio.'); ?></p>

                <p><?= traducir('El usuario entiende y acepta expresamente que cualquier tipo de contenido, software o cualquier otro tipo de material, que descargue u obtenga de cualquier otra forma a través de este sitio se realiza por su cuenta y riesgo, y que él como usuario será el único responsable de cualquier daño o pérdida de datos causado a sus sistemas informáticos.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% ha puesto todos los medios razonables para asegurar que la información que contiene este sitio es correcta. No obstante, los usuarios del sitio aceptan conocer que parte de la información contenida en este sitio podría ser incorrecta, estar incompleta o anticuada, o contener errores. %-Shop::$empresa->nombre_legal-% no asume ninguna responsabilidad al respecto.'); ?></p>

	<div  class="volver">

	</div>
</article>
	</div>
    </div>
</section>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/terminos_y_condiciones.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 12/Enero/2015
	// Versión 1.0 Términos y condiciones adaptados a los datos de configuración de la Shop::
	//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");
?>
<?php
//Marina (18/08/2020) comparo localidad y provincia para ver si son iguales, si es así una la dejo vacía.
$localidad = Shop::$empresa->localidad;
$provincia = Shop::$empresa->provincia;
if(strtolower($localidad) == strtolower($provincia)){
    $localidad ='';
}else{
     $localidad .=',';
}
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Aviso Legal & Términos de uso', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
	<div class="col-md-12">
<article id="textos_legales">
	
	      <p><?= traducir('En cumplimiento con el deber de información dispuesto en la Ley 34/2002 de Servicios de la Sociedad de la Información y el Comercio Electrónico (LSSI-CE) de 11 de julio, se facilitan a continuación los siguientes datos de información general de este sitio web:'); ?></p>

                <p><?= traducir('La titularidad de este sitio web %-Shop::$configuracion->url-%, (en adelante, sitio Web o %-Shop::$empresa->nombre-%) la ostenta: %-Shop::$empresa->nombre_legal-%, con NIF %-Shop::$empresa->cif-%, cuyos datos de contacto son:'); ?></p>

                <p><?= traducir('Dirección: %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-%, ');?><?=$localidad . $provincia;?>.</p>
                <p><?= traducir('Teléfono: (+34) %-Shop::$empresa->telefono_empresa-%'); ?></p>
                <p><?= traducir('E-Mail: %-Shop::$empresa->email_empresa-%'); ?></p>

                <p><?= traducir('El uso o el acceso a este sitio implica que usted (en adelante usuario) reconoce haber leído y comprendido las presentes condiciones legales de uso, y las acepta en su totalidad. Les rogamos por tanto que lea atentamente las presentes Condiciones, así como nuestra Política de Privacidad antes de formalizar su pedido.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% se reserva en todo caso el derecho a  revisar unilateralmente y sin previo aviso las presentes condiciones o términos de uso, así como los precios e información de los servicios que aparecen en la misma. ');?><?=traducir('Todas las modificaciones entrarán en vigor inmediatamente después de ser publicadas en este sitio. Es de la exclusiva responsabilidad de los usuarios revisar las presentes condiciones periódicamente y, en caso de no estar de acuerdo, en todo o en parte con las mismas abstenerse de utilizar nuestro sitio web.'); ?></p>

                <h3><?= traducir('Acceso y normas de utilización del sitio web'); ?></h3>
                <ul>
                    <li><?= traducir('•	%-Shop::$empresa->nombre_legal-% se reserva el derecho a modificar en cualquier momento, unilateralmente y sin necesidad de previa notificación a sus usuarios, los contenidos, la estructura, el funcionamiento o las condiciones de acceso de este sitio. Así mismo %-Shop::$empresa->nombre_legal-% se reserva el derecho a suspender temporalmente, sin necesidad de previo aviso, el acceso a este sitio para realizar operaciones de mantenimiento, actualización, mejora o de reparación.'); ?></li>

                    <li><?= traducir('•	El Usuario se obliga a utilizar la Página Web y todo su contenido y servicios conforme a lo establecido en la ley, la moral, y el orden público. Asimismo, se obliga hacer un uso adecuado de los servicios y/o contenidos de la Página Web y a no emplearlos para realizar actividades ilícitas o constitutivas de delito, que atenten contra los derechos de terceros y/o que infrinjan la regulación sobre propiedad intelectual e industrial, o cualesquiera otras normas del ordenamiento jurídico aplicable. ');?><?=traducir('%-Shop::$empresa->nombre_legal-% se reserva el derecho de anular la cuenta de aquellos Usuarios que hagan un uso inapropiado de la misma o no respeten las observaciones y prohibiciones previstas por estos Términos de Uso.'); ?></li>

                    <li><?= traducir('•	Los servicios ofrecidos en %-Shop::$configuracion->url-% se dirigen exclusivamente, a personas mayores de 18 años de edad. El usuario manifiesta y garantiza que tiene la edad legal para formalizar un contrato vinculante con %-Shop::$empresa->nombre_legal-%, y que toda la información que nos facilite a través de los formularios es exacta y veraz. '); ?></li>

                    <li><?= traducir('•	El usuario no podrá realizar ningún pedido especulativo, falso o fraudulento. Si %-Shop::$empresa->nombre_legal-% tuviera indicios razonables para considerar que se ha hecho un pedido de esta índole estará autorizado a anularlo e informar a las autoridades pertinentes.'); ?></li>

                    <li><?= traducir('•	El Usuario se obliga a mantener indemne a %-Shop::$empresa->nombre_legal-% ante cualquier posible reclamación, multa, pena o sanción que pueda venir obligada a soportar como consecuencia del incumplimiento por parte del Usuario de cualquiera de las normas de utilización antes indicadas, reservándose, además, el titular de la Página Web el derecho a solicitar la indemnización por daños y perjuicios que corresponda.'); ?></li>

                    <li><?= traducir('•	El uso de los contenidos y servicios ofrecidos por %-Shop::$empresa->nombre_legal-% será bajo el exclusivo riesgo y responsabilidad del usuario. %-Shop::$empresa->nombre_legal-% no asume ningún deber o compromiso de verificar ni de vigilar los contenidos e informaciones introducidos por los usuarios.'); ?></li>
                </ul>
                <h3><?= traducir('Privacidad'); ?></h3>
                <p><?= traducir('Puede consultar toda la información sobre el tratamiento de sus datos personales en el apartado [Política de Privacidad]'); ?></p>
                <p><?= traducir('Si desea obtener cualquier información adicional sobre nuestra Política de Privacidad puede enviar una solicitud por correo ordinario a %-Shop::$empresa->nombre_legal-%, %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-%, ');?><?=$localidad . $provincia;?><?=(', o contactar con nosotros a través del correo electrónico  a la siguiente dirección %-Shop::$empresa->email_empresa-%'); ?></p>
                <h3><?= traducir('Propiedad intelectual e industrial.'); ?></h3>

                <p><?= traducir('Todos los contenidos del sitio web %-Shop::$configuracion->url-%, incluyendo, a título enunciativo y no limitativo, las marcas comerciales, logotipos, gráficos, imágenes, archivos de sonido y vídeo, software, código de programación, textos, iconos, y los nombres que identifican servicios (en adelante "los materiales") están protegidos por los derechos de autor y otros derechos sobre la propiedad intelectual de %-Shop::$empresa->nombre_legal-% y de los demás titulares legítimos. ');?><?=traducir('Se considera reservada la reproducción en todo o en parte, de cualquier manera y bajo cualquier forma de %-Shop::$configuracion->url-% y sus contenidos sin el consentimiento explícito y por escrito de %-Shop::$empresa->nombre_legal-%'); ?></p>

                <p><?= traducir('El acceso del usuario a este sitio no implica ningún tipo de renuncia, transmisión ni cesión, total o parcial, de dichos derechos de propiedad, por esta razón, el acceso a estos contenidos o elementos no otorga, bajo ningún concepto, al usuario la posibilidad de su copia, venta, modificación, reproducción, publicación, cesión, transmisión, o creación de nuevos productos o servicios derivados de la información y elementos aquí contenidos.'); ?></p>

                <p><?= traducir('Es por ello que el usuario de este sitio no podrá, salvo previa autorización expresa y por escrito de %-Shop::$empresa->nombre_legal-%, copiar, distribuir, descargar, modificar, suprimir, borrar, alterar, publicar, transmitir, o aprovecharse de cualquier forma de los materiales que contiene.'); ?></p>

                <p><?= traducir('El usuario no adquiere derechos o licencia en relación con el servicio ni los elementos en el mismo, excepto el derecho limitado a utilizar el servicio de acuerdo con las condiciones aplicables. ');?><?=traducir('Únicamente podrá utilizar los contenidos o elementos a los que acceda a través de los servicios de %-Shop::$empresa->nombre_legal-% para su propio uso y necesidades, obligándose a no realizar ni directa, ni indirectamente una explotación comercial, ni de los servicios, ni de los materiales, elementos, o información obtenidos a través de los mismos.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% no se responsabiliza del contenido de %-Shop::$configuracion->url-% sea veraz ni de que esté debidamente actualizado. %-Shop::$empresa->nombre_legal-% no responderá de la autoría de los materiales y contenidos  de terceros de los que no sea titular, ni de posibles violaciones de derechos de propiedad intelectual frente a terceros en relación con dichos materiales.'); ?></p>

                <h3><?= traducir('Limitación de responsabilidad.'); ?></h3>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% no se responsabilizará en forma alguna de cualquier daño directo o indirecto, lucro cesante o pérdida de datos y /o clientes que se deriven del uso por parte de los usuarios o de la imposibilidad de uso de este sitio web.'); ?></p>

                <p><?= traducir('Este sitio puede contener vínculos hipertextuales (Links) y remisiones a otros sitios y páginas web que pueden no estar controlados por %-Shop::$empresa->nombre_legal-%, en estos casos %-Shop::$empresa->nombre_legal-% no se responsabilizará de los contenidos que puedan aparecer en dichas páginas.'); ?></p>

                <p><?= traducir('El usuario acepta expresamente dejar exenta a %-Shop::$empresa->nombre_legal-% de cualquier responsabilidad de los actos u omisiones del usuarios basadas en los contenidos alojados en este sitio.'); ?></p>

                <p><?= traducir('El usuario entiende y acepta expresamente que cualquier tipo de contenido, software o cualquier otro tipo de material, que descargue u obtenga de cualquier otra forma a través de este sitio se realiza por su cuenta y riesgo, y que él como usuario será el único responsable de cualquier daño o pérdida de datos causado a sus sistemas informáticos.'); ?></p>

                <p><?= traducir('%-Shop::$empresa->nombre_legal-% ha puesto todos los medios razonables para asegurar que la información que contiene este sitio es correcta. No obstante, los usuarios del sitio aceptan conocer que parte de la información contenida en este sitio podría ser incorrecta, estar incompleta o anticuada, o contener errores. %-Shop::$empresa->nombre_legal-% no asume ninguna responsabilidad al respecto.'); ?></p>

	<div  class="volver">

	</div>
</article>
	</div>
    </div>
</section>
